@@ -4,16 +4,16 @@ import rubpy.connections
 from json import dumps , loads
 from time import time
 from random import randint , choice
-from rubpy.tools import Tools
+#from rubpy.tools import Tools
 from rubpy.createMethod import createMethod
+from rubpy.tools import Tools
 
-__version__ : str = '3.0.0'
+__version__ : str = '3.1.0'
 __author__ : str = 'Shayan Heidari'
 __copyright__ : str = 'CopyRight 2022'
 
-
 class Rubika(object):
-	def __init__(self : str , auth : str , displayWelcome : bool = True) -> int:
+	def __init__(self , auth : str , displayWelcome : bool = True) -> int:
 		if displayWelcome: 
 			text : str = f'This library was created by {__author__}, with versions {__version__} and {__copyright__}.\nLibrary activated ...\n\n'
 			for char in text:
@@ -31,7 +31,7 @@ class Rubika(object):
 		self.Tool = Tools()
 		self.uploaderFile = rubpy.connections.upload
 	
-	async def getChatsUpdate(self:int) -> dict:
+	async def getChatsUpdate(self) -> dict:
 		'''This function is for
 		receiving the latest messages
 		that have been sent to your account...'''
@@ -61,6 +61,42 @@ class Rubika(object):
 		})
 		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc'))).get('data')
 
+	async def getLinkFromAppUrl(self , url : str) -> dict:
+		data : str = await self.Method.createMethod(
+		5 ,
+		"joinChannelAction" , 
+		{
+			"action" : "Join",
+			"channel_guid" : "c0i93V0298ff8aa1b8c5cf0bcb72d2d1"
+		})
+		while 1:
+			try:
+				loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
+				break
+			except:
+				continue
+		data : str = await self.Method.createMethod(
+		5 ,
+		"getLinkFromAppUrl" , 
+		{
+			"app_url" : url
+		})
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc'))).get('data').get('link').get('open_chat_data')
+
+	async def getBannedGroupMembers(self , group_guid : str) -> dict:
+		"""
+			You can get group banned users...
+		"""
+		data : str = await self.Method.createMethod(
+		5 ,
+		"getBannedGroupMembers" , 
+		{
+			"group_guid" : group_guid
+		},
+		"android"
+		)
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc'))).get('data')
+
 	async def getGroupAdmins(self , group_guid : str) -> dict:
 		'''
 			You can get the admins of a group with the group ID, just enter the group ID that starts with g in the first argument and your robot account must be in the admin group.
@@ -95,13 +131,13 @@ class Rubika(object):
 		}
 		if metaData != None:
 			Input['metadata'] = {'meta_data_parts' : metaData}
-		mode : list = ['**' , '__' , '``']
+		mode : list = ['**' , '__' , '``', '@@']
 		for check in mode:
 			if check in text:
 				metadata : list = self.Tool.textAnalysis(text)
 				Input['metadata'] = {'meta_data_parts' : metadata[0]}
 				Input['text'] = metadata[1]
-		data : dict = await self.Method.createMethod(5 , 'sendMessage', Input)
+		data : dict = await self.Method.createMethod(5 , "sendMessage", Input)
 		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
 
 	async def deleteMessages(self , chat_id : str , messages_id : list) -> dict:
